###################################################
### chunk number 1: 
###################################################
library(TRAMPR)


###################################################
### chunk number 2: 
###################################################
files <- c("demo_samples_abi.txt",
           "demo_samples_abi_template_full.csv",
           "demo_samples_abi_info_full.csv",
           "demo_samples_abi_soilcore.csv")
file.copy(system.file(files, package="TRAMPR"), ".")


###################################################
### chunk number 3: 
###################################################
load.abi.create.template("demo_samples_abi.txt")


###################################################
### chunk number 4: 
###################################################
file.rename("demo_samples_abi_template_full.csv",
            "demo_samples_abi_template.csv")


###################################################
### chunk number 5: 
###################################################
load.abi.create.info("demo_samples_abi.txt")


###################################################
### chunk number 6: 
###################################################
file.rename("demo_samples_abi_info_full.csv",
            "demo_samples_abi_info.csv")


###################################################
### chunk number 7: 
###################################################
soilcore <- read.csv("demo_samples_abi_soilcore.csv")


###################################################
### chunk number 8: 
###################################################
primer.translate <- list(ITS1F="B", ITS4=c("G", "Y"))


###################################################
### chunk number 9: 
###################################################
demo.samples <- load.abi("demo_samples_abi.txt",
                         primer.translate=primer.translate,
                         soilcore=soilcore)


###################################################
### chunk number 10: 
###################################################
data(demo.knowns)


###################################################
### chunk number 11:  eval=FALSE
###################################################
## plot(demo.knowns)


###################################################
### chunk number 12: 
###################################################
plot(demo.knowns)


###################################################
### chunk number 13: 
###################################################
fit <- TRAMP(demo.samples, demo.knowns)


###################################################
### chunk number 14:  eval=FALSE
###################################################
## plot(fit, 565)


###################################################
### chunk number 15: 
###################################################
plot(fit, 565)


###################################################
### chunk number 16:  eval=FALSE
###################################################
## pdf("TRAMP_fits.pdf")
## plot(fit)
## dev.off()


###################################################
### chunk number 17: 
###################################################
m <- summary(fit)
m[1:5, 1:5]


###################################################
### chunk number 18: 
###################################################
knowns.unk <- build.knowns(demo.samples)


###################################################
### chunk number 19:  eval=FALSE
###################################################
## knowns.sporocarps <- build.knowns(demo.samples, restrict=TRUE,
##                                   min.ratio=0)


###################################################
### chunk number 20: 
###################################################
fit <- combine(fit, knowns.unk)


###################################################
### chunk number 21: 
###################################################
demo.knowns <- combine(demo.knowns, knowns.unk)


###################################################
### chunk number 22: 
###################################################
identical(demo.knowns, fit$knowns)


###################################################
### chunk number 23:  eval=FALSE
###################################################
## demo.knowns <- fit$knowns


###################################################
### chunk number 24:  eval=FALSE
###################################################
## samples <- setdiff(labels(demo.samples), labels(demo.knowns)) 
## plot(fit, samples)


###################################################
### chunk number 25:  eval=FALSE
###################################################
## plot(fit, 221)


###################################################
### chunk number 26:  eval=FALSE
###################################################
## plot(demo.samples, 221)


###################################################
### chunk number 27: 
###################################################
fit <- add.known(fit, 221, prompt=FALSE)


###################################################
### chunk number 28: 
###################################################
names(which(summary(fit)[,"221"]))


###################################################
### chunk number 29:  eval=FALSE
###################################################
## plot(fit, 586)


###################################################
### chunk number 30: 
###################################################
plot(fit, 586)


###################################################
### chunk number 31:  eval=FALSE
###################################################
## plot(fit, 586, grouped=TRUE)


###################################################
### chunk number 32: 
###################################################
plot(fit, 586, grouped=TRUE)


###################################################
### chunk number 33:  eval=FALSE
###################################################
## fit <- update(fit)


###################################################
### chunk number 34: 
###################################################
m <- summary(fit, grouped=TRUE)
m <- m[, colSums(m) > 0]


###################################################
### chunk number 35: matrix eval=FALSE
###################################################
## cores <- fit$samples$info$soilcore.fk
## m.bycore <- aggregate(m, by=list(cores=cores), any)
## rownames(m.bycore) <- m.bycore$cores
## m.bycore <- m.bycore[-1]
## m.bycore


###################################################
### chunk number 36: 
###################################################
cores <- fit$samples$info$soilcore.fk
m.bycore <- aggregate(m, by=list(cores=cores), any)
rownames(m.bycore) <- m.bycore$cores
m.bycore <- m.bycore[-1]
m.bycore


###################################################
### chunk number 37: 
###################################################
core.veg <- soilcore$vegetation[match(rownames(m.bycore),
                                      soilcore$soilcore.pk)]


###################################################
### chunk number 38: rankabundance eval=FALSE
###################################################
## sp.freq <- sort(colSums(m.bycore), decreasing=TRUE)
## plot(sp.freq, xlab="Species rank", ylab="Species frequency", type="o",
##      pch=19)


###################################################
### chunk number 39: 
###################################################
tapply(rowSums(m.bycore), core.veg, mean)


###################################################
### chunk number 40: 
###################################################
sp.freq <- sort(colSums(m.bycore), decreasing=TRUE)
plot(sp.freq, xlab="Species rank", ylab="Species frequency", type="o",
     pch=19)


###################################################
### chunk number 41: pca eval=FALSE
###################################################
## pca <- prcomp(m.bycore)
## 
## col <- c("blue", "red")[as.integer(core.veg)]
## pch <- c(1, 3)[as.integer(core.veg)]
## 
## plot(pca$x[,1], pca$x[,2], col=col, pch=pch, xlab="PC1", ylab="PC2")
## legend("top", levels(core.veg), col=c("blue", "red"), pch=c(1, 3))


###################################################
### chunk number 42: 
###################################################
pca <- prcomp(m.bycore)

col <- c("blue", "red")[as.integer(core.veg)]
pch <- c(1, 3)[as.integer(core.veg)]

plot(pca$x[,1], pca$x[,2], col=col, pch=pch, xlab="PC1", ylab="PC2")
legend("top", levels(core.veg), col=c("blue", "red"), pch=c(1, 3))


###################################################
### chunk number 43:  eval=FALSE
###################################################
## write.TRAMPknowns(fit$knowns, "my_knowns")


###################################################
### chunk number 44:  eval=FALSE
###################################################
## my.knowns <- read.TRAMPknowns("my_knowns")


###################################################
### chunk number 45:  eval=FALSE
###################################################
## my.knowns <- fit$knowns
## save(my.knowns, file="my_knowns.Rdata")


###################################################
### chunk number 46:  eval=FALSE
###################################################
## load("my_knowns.Rdata")


